@@ -5,10 +5,9 @@ from subprocess import (
     check_output,
     CalledProcessError
 )
-from six.moves.urllib.parse import urlparse
-
 from .basic import SourceHandler
 from .exceptions import CommandFailure, DuplicateHandlerError, NoSuchHandlerError
+from ..six.moves.urllib.parse import urlparse
 
 
 def handler_types(handler_class=None):
